==> openGion_core_5.6.0.0.zip: ge/db/firebird/sql/01_TABLE/GE62S.sql <==
/**************************************************************************/
/* GE62 ( 伝送定義マスタ )                                                */
/*                                                                        */
/* Created : 2012/07/28 16:35:16                                          */
/**************************************************************************/
CREATE TABLE GE62 (
   SYSTEM_ID    VARCHAR(10)                 NOT NULL      /* 10  システムID       */
 , KBREAD       VARCHAR(20)                 NOT NULL      /* 20  読取方法         */
 , READOBJ      VARCHAR(200)                NOT NULL      /* 30  読取対象         */
 , READPRM      VARCHAR(200)                              /* 40  読取パラメーター */
 , KBEXEC       VARCHAR(20)                 NOT NULL      /* 50  実行方法         */
 , EXECDBID     VARCHAR(100)                              /* 60  実行DB接続先ID   */
 , EXECOBJ      VARCHAR(200)                NOT NULL      /* 70  実行対象         */
 , EXECPRM      VARCHAR(200)                              /* 80  実行パラメーター */
 , DMN_GRP      VARCHAR(20)                 NOT NULL      /* 90  デーモングループ */
 , DMN_TIME     NUMERIC(6)      DEFAULT 60  NOT NULL      /* 100 デーモン周期     */
 , ERROR_SENDTO VARCHAR(200)                              /* 110 エラー送信先     */
 , UNIQ         BIGINT                      NOT NULL      /* 120 ユニークキー     */
 , FGJ          VARCHAR(1)      DEFAULT '1' NOT NULL      /* 130 状態フラグ       */
 , DYSET        VARCHAR(14)                               /* 140 登録日時         */
 , PGSET        VARCHAR(10)                               /* 150 作成PG           */
 , PGPSET       VARCHAR(10)                               /* 160 作成親PG         */
 , USRSET       VARCHAR(10)                               /* 170 作成社員         */
 , DYUPD        VARCHAR(14)                               /* 180 更新日時         */
 , PGUPD        VARCHAR(10)                               /* 190 更新PG           */
 , PGPUPD       VARCHAR(10)                               /* 200 更新親PG         */
 , USRUPD       VARCHAR(10)                               /* 210 更新者           */
);

CREATE SEQUENCE GE62S00 ;


CREATE TRIGGER GE62T00 FOR GE62
  BEFORE INSERT 
  AS BEGIN 
    NEW.UNIQ = GEN_ID( GE62S00,1 );
  END;

==> openGion_core_5.6.5.1.zip: ge/db/firebird/sql/01_TABLE/GE62S.sql <==
/**************************************************************************/
/* GE62 ( 伝送定義マスタ )                                                */
/*                                                                        */
/* Created : 2013/03/27 19:06:21                                          */
/**************************************************************************/
CREATE TABLE GE62 (
   SYSTEM_ID    VARCHAR(10)                 NOT NULL      /* 10  システムID       */
 , KBREAD       VARCHAR(20)                 NOT NULL      /* 20  読取方法         */
 , READOBJ      VARCHAR(200)                NOT NULL      /* 30  読取対象         */
 , READPRM      VARCHAR(200)                              /* 40  読取パラメーター */
 , KBEXEC       VARCHAR(20)                 NOT NULL      /* 50  実行方法         */
 , EXECDBID     VARCHAR(100)                              /* 60  実行DB接続先ID   */
 , EXECOBJ      VARCHAR(200)                NOT NULL      /* 70  実行対象         */
 , EXECPRM      VARCHAR(200)                              /* 80  実行パラメーター */
 , DMN_GRP      VARCHAR(20)                 NOT NULL      /* 90  デーモングループ */
 , DMN_TIME     INTEGER         DEFAULT 60  NOT NULL      /* 100 デーモン周期     */
 , ERROR_SENDTO VARCHAR(200)                              /* 110 エラー送信先     */
 , UNIQ         BIGINT                      NOT NULL      /* 120 ユニークキー     */
 , FGJ          VARCHAR(1)      DEFAULT '1' NOT NULL      /* 130 状態フラグ       */
 , DYSET        VARCHAR(14)                               /* 140 登録日時         */
 , PGSET        VARCHAR(10)                               /* 150 作成PG           */
 , PGPSET       VARCHAR(10)                               /* 160 作成親PG         */
 , USRSET       VARCHAR(10)                               /* 170 作成社員         */
 , DYUPD        VARCHAR(14)                               /* 180 更新日時         */
 , PGUPD        VARCHAR(10)                               /* 190 更新PG           */
 , PGPUPD       VARCHAR(10)                               /* 200 更新親PG         */
 , USRUPD       VARCHAR(10)                               /* 210 更新者           */
);

CREATE SEQUENCE GE62S00 ;


CREATE TRIGGER GE62T00 FOR GE62
  BEFORE INSERT 
  AS BEGIN 
    NEW.UNIQ = GEN_ID( GE62S00,1 );
  END;
